climlab.convection
=============

.. automodule:: climlab.convection
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:

.. toctree::

    climlab.convection.convadj
    climlab.convection.EmanuelConvection
